@@ -1,4 +1,4 @@
-/* Color Selector
+ /* Color Selector
  *
  * GtkColorSelection lets the user choose a color. GtkColorSelectionDialog is
  * a prebuilt dialog containing a GtkColorSelection.
@@ -22,7 +22,7 @@ protected:
   Gtk::Frame m_Frame;
   Gtk::DrawingArea m_DrawingArea;
   Gtk::Button m_Button;
-  Gdk::Color m_Color;
+  Gdk::RGBA m_Color;
   Gtk::Alignment m_Alignment;
 };
 
@@ -35,7 +35,7 @@ Gtk::Window* do_colorsel()
 Example_ColorSel::Example_ColorSel()
 : m_VBox(false, 8),
   m_Button("_Change the above color", true),
-  m_Alignment(Gtk::ALIGN_RIGHT, Gtk::ALIGN_BOTTOM, 0.0, 0.0)
+  m_Alignment(Gtk::ALIGN_END, Gtk::ALIGN_END, 0.0, 0.0)
 {
   set_title("Color Selection");
   set_border_width(8);
@@ -53,13 +53,15 @@ Example_ColorSel::Example_ColorSel()
   // set a fixed size
   m_DrawingArea.set_size_request(200, 200);
 
+  /* TODO: Is this still necessary? It is not in the C version now.
   // Unset the background pixmap (as used by pixmap themes)
   // because it takes precedence over the background color.
   m_DrawingArea.modify_bg_pixmap(Gtk::STATE_NORMAL, "<none>");
+  */
 
   // set the color
-  m_Color.set_rgb(0, 0, 65535);
-  m_DrawingArea.modify_bg(Gtk::STATE_NORMAL, m_Color);
+  m_Color.set_rgba(0, 0, 1, 1);
+  m_DrawingArea.override_background_color(m_Color);
 
   m_Frame.add(m_DrawingArea);
 
@@ -81,19 +83,19 @@ void Example_ColorSel::on_button_clicked()
   Gtk::ColorSelectionDialog dialog ("Changing color");
   dialog.set_transient_for(*this);
 
-  Gtk::ColorSelection *const pColorSel = dialog.get_colorsel();
+  Gtk::ColorSelection *const pColorSel = dialog.get_color_selection();
 
-  pColorSel->set_previous_color(m_Color);
-  pColorSel->set_current_color(m_Color);
+  pColorSel->set_previous_rgba(m_Color);
+  pColorSel->set_current_rgba(m_Color);
   pColorSel->set_has_palette();
 
   const int response = dialog.run();
 
   if(response == Gtk::RESPONSE_OK)
   {
-    m_Color = pColorSel->get_current_color();
+    m_Color = pColorSel->get_current_rgba();
 
-    m_DrawingArea.modify_bg(Gtk::STATE_NORMAL, m_Color);
+    m_DrawingArea.override_background_color(m_Color);
   }
 }
 
