@@ -20,6 +20,10 @@
 #include "activatable.h"
 #include "adjustment.h"
 #include "alignment.h"
+#include "appchooser.h"
+#include "appchooserbutton.h"
+#include "appchooserdialog.h"
+#include "appchooserwidget.h"
 #include "application.h"
 #include "arrow.h"
 #include "aspectframe.h"
@@ -202,6 +206,9 @@ GType gtk_action_get_type(void);
 GType gtk_action_group_get_type(void);
 GType gtk_adjustment_get_type(void);
 GType gtk_alignment_get_type(void);
+GType gtk_app_chooser_button_get_type(void);
+GType gtk_app_chooser_dialog_get_type(void);
+GType gtk_app_chooser_widget_get_type(void);
 GType gtk_application_get_type(void);
 GType gtk_arrow_get_type(void);
 GType gtk_aspect_frame_get_type(void);
@@ -386,6 +393,9 @@ namespace Gtk {  class Action_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gtk {  class ActionGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Adjustment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class AppChooserButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class AppChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class AppChooserWidget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -555,12 +565,12 @@ namespace Gtk {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(gtk_builder_error_quark(), &Gtk::BuilderError::throw_func);
-  Glib::Error::register_domain(gtk_file_chooser_error_quark(), &Gtk::FileChooserError::throw_func);
-  Glib::Error::register_domain(gtk_icon_theme_error_quark(), &Gtk::IconThemeError::throw_func);
-  Glib::Error::register_domain(gtk_print_error_quark(), &Gtk::PrintError::throw_func);
-  Glib::Error::register_domain(gtk_recent_chooser_error_quark(), &Gtk::RecentChooserError::throw_func);
-  Glib::Error::register_domain(gtk_recent_manager_error_quark(), &Gtk::RecentManagerError::throw_func);
+  Glib::Error::register_domain(gtk_builder_error_quark(), &::Gtk::BuilderError::throw_func);
+  Glib::Error::register_domain(gtk_file_chooser_error_quark(), &::Gtk::FileChooserError::throw_func);
+  Glib::Error::register_domain(gtk_icon_theme_error_quark(), &::Gtk::IconThemeError::throw_func);
+  Glib::Error::register_domain(gtk_print_error_quark(), &::Gtk::PrintError::throw_func);
+  Glib::Error::register_domain(gtk_recent_chooser_error_quark(), &::Gtk::RecentChooserError::throw_func);
+  Glib::Error::register_domain(gtk_recent_manager_error_quark(), &::Gtk::RecentManagerError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gtk_about_dialog_get_type(), &Gtk::AboutDialog_Class::wrap_new);
@@ -570,6 +580,9 @@ void wrap_init()
   Glib::wrap_register(gtk_action_group_get_type(), &Gtk::ActionGroup_Class::wrap_new);
   Glib::wrap_register(gtk_adjustment_get_type(), &Gtk::Adjustment_Class::wrap_new);
   Glib::wrap_register(gtk_alignment_get_type(), &Gtk::Alignment_Class::wrap_new);
+  Glib::wrap_register(gtk_app_chooser_button_get_type(), &Gtk::AppChooserButton_Class::wrap_new);
+  Glib::wrap_register(gtk_app_chooser_dialog_get_type(), &Gtk::AppChooserDialog_Class::wrap_new);
+  Glib::wrap_register(gtk_app_chooser_widget_get_type(), &Gtk::AppChooserWidget_Class::wrap_new);
   Glib::wrap_register(gtk_application_get_type(), &Gtk::Application_Class::wrap_new);
   Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
   Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
@@ -742,6 +755,9 @@ void wrap_init()
   Gtk::ActionGroup::get_type();
   Gtk::Adjustment::get_type();
   Gtk::Alignment::get_type();
+  Gtk::AppChooserButton::get_type();
+  Gtk::AppChooserDialog::get_type();
+  Gtk::AppChooserWidget::get_type();
   Gtk::Application::get_type();
   Gtk::Arrow::get_type();
   Gtk::AspectFrame::get_type();
